"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
const json = {
    txid: "314201bdcf89846333712220ee6e7eb92f0938f62008e5315f93d54db27230d8",
    time: 1700023314,
    vout: [
        {
            value: "1000.00000000",
            n: 0,
            scriptPubKey: {
                address: "2Muzjz36gXeMR1WY9Fhkmj2PLPtdmij1uAS",
                asm: "OP_HASH160 1e2b2d5703224b39d04efd1b275e886a8d8b0935 OP_EQUAL",
                hex: "a9141e2b2d5703224b39d04efd1b275e886a8d8b093587",
            },
        },
        {
            value: "8999.99666000",
            n: 1,
            scriptPubKey: {
                address: "2MytwDpHWpdoVYQ7JzYwBPxQ5XsEdiV7udZ",
                asm: "OP_HASH160 48f290ac02c1c42fffcfef1643400a16de0f523b OP_EQUAL",
                hex: "a91448f290ac02c1c42fffcfef1643400a16de0f523b87",
            },
        },
    ],
    blocktime: 1700023314,
    mediantime: 1700023314,
    hash: "314201bdcf89846333712220ee6e7eb92f0938f62008e5315f93d54db27230d8",
    version: 1,
    size: 0,
    vsize: 0,
    weight: 0,
    locktime: 0,
    hex: "",
    blockhash: "",
    confirmations: 0,
    vin: [
        {
            sequence: 4294967295,
            txid: "5c623a651feddf7c7cb56e1a8916afabd8c840086fac4ec1cc7ef892a5b13f39",
            vout: 0,
            prevout: {
                value: "10000.00000000",
                scriptPubKey: {
                    address: "2MytwDpHWpdoVYQ7JzYwBPxQ5XsEdiV7udZ",
                    asm: "OP_HASH160 48f290ac02c1c42fffcfef1643400a16de0f523b OP_EQUAL",
                    hex: "a91448f290ac02c1c42fffcfef1643400a16de0f523b87",
                },
            },
        },
    ],
};
describe(`doge indexed transaction test ,(${(0, testUtils_1.getTestFile)(__filename)})`, function () {
    const tx = new src_1.DogeTransaction(json);
    it("should compute payment summary", function () {
        const summary = tx.paymentSummary({ inUtxo: 0, outUtxo: 0 });
        (0, chai_1.expect)(summary).to.not.be.undefined;
        (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentSummaryStatus.Success);
        (0, chai_1.expect)(summary.response).to.not.be.undefined;
        (0, chai_1.expect)(summary.response?.receivedAmount).to.eq(100000000000n);
        (0, chai_1.expect)(summary.response?.spentAmount).to.eq(1000000000000n - 899999666000n);
    });
    it("should compute payment summary", function () {
        const summary = tx.paymentSummary({ inUtxo: 0, outUtxo: 1 });
        (0, chai_1.expect)(summary).to.not.be.undefined;
        (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentSummaryStatus.Success);
        (0, chai_1.expect)(summary.response).to.not.be.undefined;
        (0, chai_1.expect)(summary.response?.receivedAmount).to.eq(-1000000000000n + 899999666000n);
        (0, chai_1.expect)(summary.response?.spentAmount).to.eq(1000000000000n - 899999666000n);
    });
    it("should compute balance decreasing summary", function () {
        const summary = tx.balanceDecreasingSummary((0, src_1.standardAddressHash)("2MytwDpHWpdoVYQ7JzYwBPxQ5XsEdiV7udZ"));
        (0, chai_1.expect)(summary).to.not.be.undefined;
        (0, chai_1.expect)(summary.status).to.eq(src_1.BalanceDecreasingSummaryStatus.Success);
        (0, chai_1.expect)(summary.response).to.not.be.undefined;
        (0, chai_1.expect)(summary.response?.spentAmount).to.eq(1000000000000n - 899999666000n);
    });
});
//# sourceMappingURL=indexedTransacation.test.js.map