"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
const XRPMccConnection = {
    url: process.env.XRP_URL || "",
    username: process.env.XRP_USERNAME || "",
    password: process.env.XRP_PASSWORD || "",
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
    rateLimitOptions: {
        timeoutMs: 15000,
    },
};
describe(`Block Xrp base test (${(0, testUtils_1.getTestFile)(__filename)})`, function () {
    let MccClient;
    let status;
    before(async function () {
        MccClient = new src_1.MCC.XRP(XRPMccConnection);
        status = await (0, src_1.retry)("", () => MccClient.getNodeStatus());
    });
    it("Should get status version ", async function () {
        const version = status.version.split("_");
        console.log(version);
        (0, chai_1.expect)(version[0]).to.be.oneOf(["2.2.2", "2.3.0"]);
    });
    it("Should get status state ", async function () {
        (0, chai_1.expect)(status.state).to.be.eq("full");
    });
    it("Should get status isHealthy ", async function () {
        (0, chai_1.expect)(status.isHealthy).to.eq(true);
    });
    it("Should get status isSynced ", async function () {
        (0, chai_1.expect)(status.isSynced).to.eq(true);
    });
});
describe(`Xrp bottom block (${(0, testUtils_1.getTestFile)(__filename)})`, function () {
    let MccClient;
    before(async function () {
        MccClient = new src_1.MCC.XRP(XRPMccConnection);
    });
    it("Should get status version ", async function () {
        const bottom = await (0, src_1.retry)("", () => MccClient.getBottomBlockHeight());
        (0, chai_1.expect)(bottom).to.greaterThanOrEqual(32570);
    });
});
//# sourceMappingURL=status.test.js.map